# v0.24.x series

## v0.24.0 (7th August 2023)

Release highlights:

* This is mainly a fix release. Thanks to our users for raising issues!
* An experimental interface to mesh-based preset canopies is added. The
  currently distributed data is limited to the Wellington Citrus Orchard scene;
  it will be expanded in the coming releases.

### Added

* ⚠️ Added data files and APIs for the Wellington Citrus Orchard scene
  ({ghpr}`327`). This is an experimental feature, use with caution and report
  issues.

### Changed

* 📖 Our change log now adheres [Keep a Changelog](https://keepachangelog.com).
* Our versioning scheme now adheres [ZeroVer](https://0ver.org).

### Fixed

* Added missing lookup strategy for participating medium parameters of the
  {class}`.HomogeneousAtmosphere` ({ghpr}`352`).
* Fixed a bug where the kernel dictionary emitted by the {class}`.MQDiffuseBSDF`
  wrapper would miss a data point on the azimuth dimension ({ghpr}`353`).
* Fixed a bug where an incorrect flag field init type would raise a `TypeError`
  on Python 3.11 ({ghpr}`358`).
* Fixed a bug where the init context could fall out of the range covered by the
  loaded spectral dataset ({ghpr}`360`).

## v0.24.1 (30th August 2023)

*Yanked release.*

## v0.24.2 (31st August 2023)

This is a fix release.

### Fixed

* Set default units of the `*SpectralIndex.w` field to `ucc['wavelength']`
  ({ghpr}`362`).
* Fixed pinned dependency versions for the PyPI wheel ({ghpr}`364`).
* Fixed circular imports in the `scenes.biosphere` subpackage
  ({ghcommit}`5f6284`).

## v0.24.3 (18th September 2023)

This is a fix release. It ensures compatibility with current xarray versions
(v2023.8 and later).

### Fixed

* Fixed download list path in the data module CLI ({ghpr}`368`).
* Added missing dependency `importlib-resources` to requirement list
  ({ghpr}`368`).
* Fixed xarray usage in {meth}`.AFGL1986RadProfile.eval_sigma_a_ckd` to allow
  usage with recent xarray version (2023.8 and later) ({ghpr}`368`).

## v0.24.4 (11th October 2023)

This is a minor feature release. Adds an option to set a timeout to radiometric
kernel runs and fixes a few bugs.

### Added

* All {class}`.Integrator` classes now have a `timeout` parameter ({ghpr}`370`).

### Changed

* The `eradiate show` command-line diagnostic tool now reports on dependency
  versions.

### Fixed

* The {class}`.CheckerboardBSDF` class's `scale_pattern` parameter now
  behaves as intended ({ghpr}`372`).
* The post-processing pipeline now skips SRF weighting when using a multi-delta
  SRF in CKD mode with a {class}`.DistantFluxMeasure` ({ghcommit}`fac33c`).
